@@ -38,6 +38,7 @@ macro_rules! unreachable {
 mod basic;
 
 mod alloc_api;
+mod global_bulk;
 
 #[macro_use]
 mod pod;
@@ -48,5 +49,6 @@ mod hashref;
 pub use alloc_api::*;
 pub use basic::*;
 pub use bump::*;
+pub use global_bulk::*;
 pub use hashref::*;
 pub use pod::*;
